import Image from "next/image";

import { ContentLines } from "@/components/shared/content-lines";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";

import { BreadcrumbItem, CustomBreadcrumb } from "../common/breadcrumb";

interface PageBreadcrumbProps {
	backgroundImage: string;
	subtitle: Record<Locale, string>;
	title: Record<Locale, string>;
	breadcrumbItems: BreadcrumbItem[];
	locale: Locale;
}

export function PageBreadcrumb({
	backgroundImage,
	subtitle,
	title,
	breadcrumbItems,
	locale,
}: PageBreadcrumbProps) {
	const isRTL = locale === "ar";

	return (
		<section className="relative">
			{/* Background Image with Overlay */}
			<div className="absolute inset-0">
				<Image
					src={backgroundImage}
					alt=""
					fill
					className="z-40 object-cover"
					priority
				/>
				<div className="absolute inset-0 z-50 bg-black/50" />
			</div>

			{/* Content Container */}
			<div className="container relative z-50 px-4 py-16 md:px-6 lg:px-24">
				<div className="flex max-h-[240px] flex-col">
					{/* Main Content */}
					<div className="flex flex-1 flex-col">
						<ContentLines
							title={subtitle?.[locale]}
							underlineColor="custom-primary-accent"
							textColor="text-blue-400"
							padding="none"
						/>
						<h1
							className={cn(
								"mt-4 text-xl font-bold text-white md:text-2xl",
								isRTL && "text-right"
							)}
						>
							{title?.[locale]}
						</h1>
					</div>

					{/* Breadcrumb */}
					<div
						className={cn("mt-8 flex", isRTL ? "justify-end" : "justify-start")}
					>
						<CustomBreadcrumb items={breadcrumbItems} locale={locale} />
					</div>
				</div>
			</div>
		</section>
	);
}
